=================================
 Celery - Distributed Task Queue
=================================

Celery is a simple, flexible and reliable distributed system to
process vast amounts of messages, while providing operations with
the tools required to maintain such a system.

It's a task queue with focus on real-time processing, while also
supporting task scheduling.

Celery has a large and diverse community of users and contributors,
you should come join us :ref:`on IRC <irc-channel>`
or :ref:`our mailing-list <mailing-list>`.

Celery is Open Source and licensed under the `BSD License`_.

Getting Started
===============

- If you are new to Celery you can get started by following
  the :ref:`first-steps` tutorial.

- You can also check out the :ref:`FAQ <faq>`.

.. _`BSD License`: http://www.opensource.org/licenses/BSD-3-Clause

Contents
========

.. toctree::
    :maxdepth: 1

    copyright

.. toctree::
    :maxdepth: 2

    getting-started/index
    userguide/index

.. toctree::
    :maxdepth: 1

    configuration
    django/index
    contributing
    community
    tutorials/index
    faq
    changelog
    whatsnew-3.1
    whatsnew-3.0
    whatsnew-2.5
    reference/index
    internals/index
    history/index
    glossary


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

